#pragma once
#ifndef CLOSEST_ADJ_POP_H
#define CLOSEST_ADJ_POP_H

#include "smc_base.h"

int closest_adj_pop(IntegerVector adj,
                int i_dist,
                NumericVector g_prop);

#endif
